@@ -9,3 +9,10 @@ def camel_to_snake(name):
 
 def is_collection(collection):
     return hasattr(collection, '__iter__') and hasattr(collection, '__getitem__')
+
+
+def get_first_element(collect, eq_func):
+    for i in collect:
+        if eq_func(i):
+            return i
+    return None
